unit DList;

interface

uses Classes, Controls;

type

  TDListDialog = class(TComponent)
  private
    FTitle: PString;
    FLabel1Caption: TCaption;
    FLabel2Caption: TCaption;
    FList1: TStrings;
    FList2: TStrings;
    function GetTitle: string;
    procedure SetTitle(const ATitle: string);
    procedure SetList1(Value: TStrings);
    procedure SetList2(Value: TStrings);
    function IsLabel1Custom: Boolean;
    function IsLabel2Custom: Boolean;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    function Execute: Boolean;
  published
    property Title: string read GetTitle write SetTitle;
    property Label1Caption: TCaption read FLabel1Caption write FLabel1Caption
      stored IsLabel1Custom;
    property Label2Caption: TCaption read FLabel2Caption write FLabel2Caption
      stored IsLabel2Custom;
    property List1: TStrings read FList1 write SetList1;
    property List2: TStrings read FList2 write SetList2;
  end;

implementation

uses SysUtils, Forms, FDualLst, Consts, RxTConst, VCLUtils;

{ TDListDialog }

constructor TDListDialog.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FTitle := NullStr;
  FList1 := TStringList.Create;
  FList2 := TStringList.Create;
  FLabel1Caption := LoadStr(SDualListSrcCaption);
  FLabel2Caption := LoadStr(SDualListDestCaption);
end;

destructor TDListDialog.Destroy;
begin
  List1.Free;
  List2.Free;
  DisposeStr(FTitle);
  inherited Destroy;
end;

function TDListDialog.GetTitle: string;
begin
  Result := FTitle^;
end;

procedure TDListDialog.SetTitle(const ATitle: string);
begin
  AssignStr(FTitle, ATitle);
end;

procedure TDListDialog.SetList1(Value: TStrings);
begin
  FList1.Assign(Value);
end;

procedure TDListDialog.SetList2(Value: TStrings);
begin
  FList2.Assign(Value);
end;

function TDListDialog.IsLabel1Custom: Boolean;
begin
  Result := CompareStr(Label1Caption, LoadStr(SDualListSrcCaption)) <> 0;
end;

function TDListDialog.IsLabel2Custom: Boolean;
begin
  Result := CompareStr(Label2Caption, LoadStr(SDualListDestCaption)) <> 0;
end;

function TDListDialog.Execute: Boolean;
var
  Form: TDualListForm;
begin
  Form := TDualListForm.Create(Application);
  try
    with Form do begin
      Ctl3D := True;
      if NewStyleControls then Font.Style := [];
      ShowHelp := False;
      SrcList.Items := List1;
      DstList.Items := List2;
      if Self.Title <> '' then Form.Caption := Self.Title;
      if Label1Caption <> '' then SrcLabel.Caption := Label1Caption;
      if Label2Caption <> '' then DstLabel.Caption := Label2Caption;
    end;
    Result := (Form.ShowModal = mrOk);
    if Result then begin
      List1 := Form.SrcList.Items;
      List2 := Form.DstList.Items;
    end;
  finally
    Form.Free;
  end;
end;

end.
